@@ -94,7 +94,7 @@ def convert_to_list(obj):
 ############################################## One-game rink map function ##############################################
 
 def game_rink_map(data, good_team = None, title = None, size = None, strengths = ['all', '5v5', 'PP', 'SH', 'EV', '3v3'],
-                        colors = None, save_img = False, annotations = False, default_colors = NHL_COLORS):
+                        colors = None, save_img = False, annotations = False, default_colors = NHL_COLORS, size_multiplier = 500):
     
     '''
     Function to normalize coordinates to one zone
@@ -311,7 +311,7 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
                     
                 else:
                     
-                    s = event_df[size] * 500
+                    s = event_df[size] * size_multiplier
                 
                 rink.scatter(event_df.norm_coords_x, event_df.norm_coords_y, c = color, label = result, s = s, alpha = 0.8,
                     ax = ax, edgecolors = edge_color, is_constrained = True, zorder = zorder_dict[result])
@@ -327,7 +327,7 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
                             
                             ax.annotate(event_df['event_player_1'][idx],
                                         (event_df['new_x'][idx], event_df['new_y'][idx]),
-                                        bbox=dict(boxstyle = 'round', fc="white", ec="gray", alpha = 0.75)
+                                        bbox=dict(boxstyle = 'round', fc = 'white', ec = 'gray', alpha = 0.675)
                                        ).set_zorder(1000)
                     
                     #for i in range(len(x)):
@@ -353,5 +353,7 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
 
                 os.makedirs('rink_plots')
 
-            fig.savefig(f'rink_plots/{good_team}_{bad_team}_{strength}_{game_date}.png', dpi = 750, bbox_inches = 'tight', facecolor = 'white')
+                file_name = os.path.join('rink_plots', f'{good_team}_{bad_team}_{strength}_{game_date}.png')
+
+            fig.savefig(file_name, dpi = 750, bbox_inches = 'tight', facecolor = 'white')
 
